sphinx-notfound-page
====================

Create a custom 404 page with absolute URLs hardcoded.

**Strongly** based on @ericholscher's solution from https://github.com/rtfd/readthedocs.org/issues/353
